/*
*	RBC		: Model 1
*	Author	: Pham Thai Binh
*/
close all;

var Y C W H K I Rb rk vareps_a vareps_g vareps_i vareps_z;
var ln_Y ln_C ln_K ln_I ln_H ln_W ln_Rb ln_rk;

varexo eps_z eps_a eps_i eps_g;

parameters 	betta delta chi alpha xi_g sigma_L
			rhoA rhoI rhoG rhoZ
			Css Iss Kss Hss Wss Yss Rbss rkss;
			
rhoA  = 0.95;
rhoI  = 0.95;
rhoG  = 0.95;
rhoZ  = 0.95;
betta = 0.9;
delta = 0.15;
alpha = 0.6;
xi_g  = 0.20;
sigma_L = 1;
Rbss  = 1/betta;
rkss  = Rbss - 1 + delta;

Hss   = 1/3;
Kss   = Hss/(((Rbss-1+delta)*(1/alpha))^(1/(1-alpha)));
Wss   = (1-alpha)*(Kss/Hss)^alpha;
Iss   = delta*Kss;
Yss   = (Kss^alpha)*(Hss^(1-alpha));
Css   = Yss - Iss - xi_g*Yss;
chi   = Wss/(Css*Hss^sigma_L);

model;

betta*Rb = (vareps_z/vareps_z(+1))*(C(+1)/C);

W = (chi/vareps_z)*H^sigma_L*C;

K = vareps_i*I + (1-delta)*K(-1);

Rb/vareps_i = (1-delta)/vareps_i(+1) + rk(+1);

Y = vareps_a*(K(-1)^alpha)*(H^(1-alpha));

rk = alpha*Y/K(-1);

W = (1-alpha)*Y/H;

Y = C + I + vareps_g*xi_g*Yss;

log(vareps_a) = rhoA*log(vareps_a(-1)) + eps_a;

log(vareps_g) = rhoG*log(vareps_g(-1)) + eps_g;

log(vareps_i) = rhoI*log(vareps_i(-1)) + eps_i;

log(vareps_z) = rhoZ*log(vareps_z(-1)) + eps_z;

	% Linearized counterpart
	ln_Y = log(Y/STEADY_STATE(Y));
	ln_C = log(C/STEADY_STATE(C));
	ln_K = log(K/STEADY_STATE(K));
	ln_I = log(I/STEADY_STATE(I));
	ln_H = log(H/STEADY_STATE(H));
	ln_W = log(W/STEADY_STATE(W));
	ln_Rb = log(Rb/STEADY_STATE(Rb));
	ln_rk = log(rk/STEADY_STATE(rk));

end;

initval;
C = Css;
K = Kss;
I = Iss;
H = Hss;
W = Wss;
Y = Yss;
Rb = Rbss;
rk = rkss;
vareps_a = 1;
vareps_g = 1;
vareps_i = 1;
vareps_z = 1;
ln_Y = 0;
ln_C = 0;
ln_K = 0;
ln_I = 0;
ln_H = 0;
ln_W = 0;
ln_Rb = 0;
ln_rk = 0;
end;

shocks;
	var eps_a;  stderr 0.01;
	var eps_g;  stderr 0.01;
	var eps_i;  stderr 0.01;
	var eps_z;  stderr 0.01;
end;

steady;

stoch_simul(irf=60, periods=750) ln_Y ln_C ln_K ln_I ln_H ln_W ln_Rb ln_rk;

varobs ln_Y;

estimated_params;

	rhoA, beta_pdf, 0.95, 0.05;
    betta, beta_pdf, 0.98, 0.02;
    delta, beta_pdf, 0.03, 0.005;
end;

estimation(datafile=model1_datafile, first_obs=1,  nobs=67, mh_replic=20000, 
mh_nblocks=2, mh_drop=0.45, mh_jscale=0.4, mode_compute=4, irf=30) ln_Y ln_C ln_K;